.. _getting_started:

===============
Getting Started
===============

After installation, you can use AltamISA in your project simply by importing the module.

.. code-block:: python

    from altamisa.isatab import *

That's all, continue and look at the list of examples.
